--[[

$Revision: 32 $

(C) Copyright 2009 Bethink (bethink at naef dot com)
See LICENSE.txt for license terms.

]]


----------------------------------------------------------------------
-- Initialization

local L = LibStub("AceLocale-3.0"):GetLocale("BossNotes")


----------------------------------------------------------------------
-- Encounters

BOSS_NOTES_ENCOUNTERS = {
	-- Wrath of the Lich King Raid
	{
		instanceSetId = "WotlkRaid",
		default = true,
		instances = {
			{
				instanceId = "Naxxramas",
				encounters = {
					{
						-- Anub'rekhan
						encounterId = 15956,
						npcIds = { 15956, 16573 }
					},
					{
						-- Grand Widow Faerlina
						encounterId = 15953,
						npcIds = { 15953, 16505, 16506},
					},
					{
						-- Maexxna
						encounterId = 15952
					},
					{
						-- Noth the Plaguebringer
						encounterId = 15954,
						npcIds = { 15954, 16981, 16982, 16983, 16984 }
					},
					{
						-- Heigan the Unclean
						encounterId = 15936
					},
					{
						-- Loatheb
						encounterId = 16011,
						npcIds = { 16011, 16286 }
					},
					{
						-- Instructor Razuvious
						encounterId = 16061,
						npcIds = {16061, 16803 }
						
					},
					{
						-- Gothik the Harvester
						encounterId = 16060,
						npcIds = { 16060, 16124, 16125, 16126, 16127, 16148, 16149, 16150 }
						
					},
					{
						-- The Four Horsemen
						encounterId = 16063,
						npcIds = { 16063, 16064, 16065, 30549 }
					},
					{
						-- Patchwerk
						encounterId = 16028
					},
					{
						-- Grobbulus
						encounterId = 15931,
						npcIds = { 15931, 16290 }
					},
					{
						-- Gluth
						encounterId = 15932,
						npcIds = { 15932, 16360 }
					},
					{
						-- Thaddius
						encounterId = 15928,
						npcIds = { 15928, 15929, 15930 }
					},
					{
						-- Sapphiron
						encounterId = 15989
					},
					{
						-- Kel'Thuzad
						encounterId = 15990,
						npcIds = { 15990, 16427, 16428, 16429, 16441 }
					}
				}
			},
			{
				instanceId = "TheEyeOfEternity",
				encounters = {
					{
						-- Malygos
						encounterId = 29655,
						npcIds = { 29655, 30084, 30245, 30429 }
					}
				}
			},
			{
				instanceId = "TheObsidianSanctum",
				encounters = {
					{
						-- Sartharion
						encounterId = 28860,
						npcIds = { 28860, 30449, 30451, 30452, 31218, 31219 }
					}
				}
			},
			{
				instanceId = "VaultOfArchavon",
				encounters = {
					{
						-- Archavon the Stone Watcher
						encounterId = 31125
					}
				}
			}
		}
	},
	
	-- Wrath of the Lich King Dungeons
	{
		instanceSetId = "WotlkDungeon",
		default = true,
		instances = {
			{
				instanceId = "HallsOfLightning",
				encounters = {
					{
						-- General Bjarngrim
						encounterId = 28586
					},
					{
						-- Volkhan
						encounterId = 28587
					},
					{
						-- Ionar
						encounterId = 28546
					},
					{
						-- Loken
						encounterId = 28923
					}
				}
			},
			{
				instanceId = "TheCullingOfStratholme",
				encounters = {
					{
						-- Meathook
						encounterId = 26529
					},
					{
						-- Salramm the Fleshcrafter
						encounterId = 26530
					},
					{
						-- Chrono-Lord Epoch
						encounterId = 26532
					},
					{
						-- Mal'Ganis
						encounterId = 26533
					},
					{
						-- Infinite Corruptor
						encounterId = 32273
					}
				}
			},
			{
				instanceId = "TheOculus",
				encounters = {
					{
						-- Drakos The Interrogator
						encounterId = 27654
					},
					{
						-- Varos Cloudstrider
						encounterId = 27447
					},
					{
						-- Mage-Lord Urom
						encounterId = 27655
					},
					{
						-- Ley-Guardian Eregos
						encounterId = 27656
					}
				}
			},
			{
				instanceId = "UtgardePinnacle",
				encounters = {
					{
						-- Svala Sorrowgrave
						encounterId = 26668
					},
					{
						-- Gortok Palehoof
						encounterId = 26687
					},
					{
						-- Skdadi the Ruthless
						encounterId = 26693
					},
					{
						-- King Ymiron
						encounterId = 26861
					}
				}
			},
			{
				instanceId = "HallsOfStone",
				encounters = {
					{
						-- Maiden of Grief
						encounterId = 27975
					},
					{
						-- Krystallus
						encounterId = 27977
					},
					{
						-- Tribunal of Ages
						encounterId = 27983,
						npcIds = { 27983, 27984, 27985 }
					},
					{
						-- Sjonnir The Ironshaper
						encounterId = 27978
					}
				}
			},
			{
				instanceId = "Gundrak",
				encounters = {
					{
						-- Slad'ran
						encounterId = 29304
					},
					{
						-- Drakkari Colossus
						encounterId = 29307,
						npcIds = { 29307, 29573 }
					},
					{
						-- Moorabi
						encounterId = 29305
					},
					{
						-- Gal'darah
						encounterId = 29306
					},
					{
						-- Eck the Ferocious
						encounterId = 29932
					}
				}
			},
			{
				instanceId = "TheVioletHold",
				encounters = {
					{
						-- Erekem
						encounterId = 29315
					},
					{
						-- Moragg
						encounterId = 29316
					},
					{
						-- Ichoron
						encounterId = 29313
					},
					{
						-- Xevozz
						encounterId = 29266
					},
					{
						-- Lavanthor
						encounterId = 29312
					},
					{
						-- Zuramat The Obliterator
						encounterId = 29314
					},
					{
						-- Cayanigosa
						encounterId = 31134
					}
				}
			},
			{
				instanceId = "DrakTharonKeep",
				encounters = {
					{
						-- Trollgore
						encounterId = 26630
					},
					{
						-- Novos The Summonor
						encounterId = 26631
					},
					{
						-- Kind Dred
						encounterId = 27483
					},
					{
						-- The Prophet Tharon'ja
						encounterId = 26632
					}
				}
			},
			{
				instanceId = "AhnKahetTheOldKingdom",
				encounters = {
					{
						-- Elder Nadox
						encounterId = 29309
					},
					{
						-- Prince Taldaram
						encounterId = 29308
					},
					{
						-- Jedoga Shadowseeker
						encounterId = 29310
					},
					{
						-- Herald Volazj
						encounterId = 29311
					},
					{
						-- Amanitar
						encounterId = 30258
					}
				}
			},
			{
				instanceId = "AzjolNerub",
				encounters = {
					{
						-- Krik'thir the Gatewatcher
						encounterId = 28684
					},
					{
						-- Hadronox
						encounterId = 28921
					},
					{
						-- Anub'arak
						encounterId = 29120
					}
				}
			},
			{
				instanceId = "TheNexus",
				encounters = {
					{
						-- Grand Magus Telestra
						encounterId = 26731,
						npcIds = { 26731, 29928, 26929, 26930 }
					},
					{
						-- Anomalus
						encounterId = 26763
					},
					{
						-- Ormorok The Tree-Shaper
						encounterId = 26794
					},
					{
						-- Keristrsza
						encounterId = 27723
					},
					{
						-- Commander Stoutbeard
						encounterId = 26795
					},
					{
						-- Commander Kolurg
						encounterId = 26798
					}
				}
			},
			{
				instanceId = "UtgardeKeep",
				encounters = {
					{
						-- Prince Keleseth
						encounterId = 23953
					},
					{
						-- Skarvald & Dalronn
						encounterId = 24200,
						npcIds = { 24200, 24201 }
					},
					{
						-- Ingvar the Punderer
						encounterId = 23954
					}
				}
			}
		}
	},
	
	-- The Burning Crusade Raid
	{
		instanceSetId = "TbcRaid",
		default = false,
		instances = {
		}
	},
	
	-- The Burning Crusade Dungeon
	{
		instanceSetId = "TbcDungeon",
		default = false,
		instances = {
		}
	},
	
	-- Classic Raid
	{
		instanceSetId = "ClassicRaid",
		default = false,
		instances = {
		}
	},
	
	-- Classic Dungeon
	{
		instanceSetId = "ClassicDungeon",
		default = false,
		instances = {
		}
	}
}

-- Fixup
for _, instanceSet in ipairs(BOSS_NOTES_ENCOUNTERS) do
	instanceSet.name = L[instanceSet.instanceSetId]
	for _, instance in ipairs(instanceSet.instances) do
		instance.name = L["instance:" .. instance.instanceId]
		for _, encounter in ipairs(instance.encounters) do
			encounter.name = L["encounter:" .. encounter.encounterId]
			if not encounter.npcIds then
				encounter.npcIds = { encounter.encounterId }
			end
		end
	end
end
